<?php

/* ************************************************* *\
|* ================================================= *|
|* =       Copyright (c) 2012 Jacob Pollack.       = *|
|* ================================================= *|
|* = THIS SOFTWARE IS PRIVATE AND CANNOT BE FOUND  = *|
|* = ON THE PUBLIC DOMAIN. ANY DISTRIBUTION OR USE = *|
|* = OF THIS SOFTWARE WITHOUT THE EXPLICIT         = *|
|* = PERMISSION OF THE AUTHOR WILL RESULT IN LEGAL = *|
|* = ACTION BEING TAKEN.                           = *|
|* =                                               = *|
|* = THIS SOFTWARE IS CREATED FOR EDUCATIONAL      = *|
|* = PURPOSES ONLY. CHANGES OF ANY SORT MUST BE    = *|
|* = SUBMITTED TO THE RESPOSITORY ACCORDINGLY.     = *|
|* ================================================= *|
|* = @author    Jacob Pollack                      = *|
|* = @email     jacobpollack@jamach.com            = *|
|* = @date      05/08/2012 (DD/MM/YYYY)            = *|
|* =                                               = *|
|* = @contributors  none                           = *|
|* ================================================= *|
\*************************************************** */

/**
 * This is the loading file which handles all of the class
 * loading.
 * 
 * @name    Loader
 * @author  Jacob Pollack
 */

/**
 * Registers the autoload method.
 * 
 * @deprecated   The '__autoload' magic method will be
 * outdated and deprecated soon.
 * @see __autoload($class)
 */
spl_autoload_register('autoload');

/**
 * Dynamically loads a class file when the class is instantiated. The class
 * argument is the name (including namespaces) of the class to be loaded. It
 * does not return anything.
 * 
 * Namespaces are not used throughout the core of the software although modules
 * and other external scripts may use them.
 * 
 * @param   string  $class  Name of the class (including namespaces) to be loaded.
 * 
 * @return  void
 */
function autoload($class)
{
    $file = null;
    $class_parts = explode('\\', $class);
    
    if (sizeof($class_parts) > 1)
    {
        $file = end($class_parts);
    }
    else
    {
        $file = current($class_parts);
    }
    
    try
    {
        require_once CWD . INCLUDES . WRAPPERS . strtolower($file) . '.php';
    }
    catch (Exception $e)
    {
        trigger_error($e->getMessage());
    }
}

?>