<?php

/* ************************************************* *\
|* ================================================= *|
|* =       Copyright (c) 2012 Jacob Pollack.       = *|
|* ================================================= *|
|* = THIS SOFTWARE IS PRIVATE AND CANNOT BE FOUND  = *|
|* = ON THE PUBLIC DOMAIN. ANY DISTRIBUTION OR USE = *|
|* = OF THIS SOFTWARE WITHOUT THE EXPLICIT         = *|
|* = PERMISSION OF THE AUTHOR WILL RESULT IN LEGAL = *|
|* = ACTION BEING TAKEN.                           = *|
|* =                                               = *|
|* = THIS SOFTWARE IS CREATED FOR EDUCATIONAL      = *|
|* = PURPOSES ONLY. CHANGES OF ANY SORT MUST BE    = *|
|* = SUBMITTED TO THE RESPOSITORY ACCORDINGLY.     = *|
|* ================================================= *|
|* = @author    Jacob Pollack                      = *|
|* = @email     jacobpollack@jamach.com            = *|
|* = @date      05/08/2012 (DD/MM/YYYY)            = *|
|* =                                               = *|
|* = @contributors  none                           = *|
|* ================================================= *|
\*************************************************** */

/**
 * This is the environment class file. Handles all of the
 * core functionality and structure surrounding the 
 * software.
 * 
 * @name    Environment
 * @author  Jacob Pollack
 */

final class environment
{
    /**
     * Start time of the script.
     * 
     * @var float
     */
    private $start_time = -1;
    
    /**
     * End time of the script.
     * 
     * @var float
     */
    private $end_time = -1;
    
    /**
     * An array of accessible properties to get and set.
     * 
     * @var array
     */
    private $properties = array(
    'start_time',
    'end_time',
    'configuration',
    'object'
    );
    
    /**
     * Configuration object.
     * 
     * @var object  (stdClass)
     */
    private $configuration = null;
    
    /**
     * An object that contains all of the core objects.
     * 
     * @var object  (stdClass)
     */
    private $object = null;
    
    /**
     * Constructs the environment and loads the local properties.
     * 
     * @param   stdClass    $object     Empty PHP object passed by reference (stdClass).
     * 
     * @return  void
     */
    final public function __construct(stdClass &$object)
    {
        if ($this->start_time == -1)
        {
            $this->start_time = microtime(true);
        }
        
        $this->object = &$object;
    }
    
    /**
     * Sets data to inaccessible properties.
     * 
     * @param   string  $property   The name of the property being requested.
     * @param   string  $value      The new value.
     * 
     * @return  void
     * @return  null
     */
    final public function __set($property, $value)
    {
        if (in_array($property, $this->properties) == true)
        {
            $this->$property = $value;
        }
        
        return null;
    }
    
    /**
     * Reads data from inaccessible properties.
     * 
     * @param   string  $property   The name of the property being requested.
     * 
     * @return  object
     */
    final public function __get($property)
    {
        if (in_array($property, $this->properties) == true)
        {
            return $this->$property;
        }
        
        return null;
    }
    
    /**
     * Loads the configuration file and casts the array of configurations to the 
     * configuration object.
     * 
     * @return  void
     */
    final public function load_configuration()
    {
        $path = CWD . INCLUDES . 'configuration.php';
        
        if (file_exists($path) == true)
        {
            require_once $path;
            
            if (is_array($config) == true)
            {
                $this->configuration = array_to_object_cache('configuration', $config);
                
                // Deletes the configuration array.
                delete($config);
            }
            else
            {
                trigger_error('Configuration variables could not be found.');
            }
        }
        else
        {
            trigger_error('Configuration file not found.');
        }
    }
    
    /**
     * Empty destructor.
     * 
     * @return  void
     */
    final public function __destruct() { }
}

?>